package services

import (
	"errors"
	"fmt"
	"hongze/hongze_cygx/models"
	"hongze/hongze_cygx/utils"
	"strconv"
	"strings"
	"time"
)

// 研选专栏有新内容审核通过时，给关注此专栏的客户发送模板消息
func SendWxMsgSpecialFollow(specialId int) (err error) {
	var msg string
	defer func() {
		if err != nil {
			go utils.SendEmail("发送模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format("2006-01-02 15:04:05"), msg+";Err:"+err.Error(), utils.EmailSendToUsers)
			go utils.SendAlarmMsg(fmt.Sprint("研选专栏有新内容审核通过时，给关注此专栏的客户发送模板消息失败", specialId, ", specialId"), 2)
			utils.FileLog.Info("发送模版消息失败,Err:%s", err.Error())
		}
	}()
	var first string
	var keyword1 string
	var keyword2 string
	var keyword3 string
	var keyword4 string
	var remark string

	followers, e := models.GetYanxuanSpecialFollowUserById(specialId)
	if e != nil {
		err = errors.New("GetYanxuanSpecialFollowUserById, Err: " + e.Error())
		return
	}

	specialItem, e := models.GetYanxuanSpecialItemById(specialId)
	if e != nil {
		err = errors.New("GetYanxuanSpecialFollowUserById, Err: " + e.Error())
		return
	}
	var allInUserId string
	for _, v := range followers {
		allInUserId += strconv.Itoa(v) + ","
	}

	allInUserId = strings.TrimRight(allInUserId, ",")

	userList, err := models.GetWxUserListByUserIds(allInUserId)
	if err != nil && err.Error() != utils.ErrNoRow() {
		return err
	}

	mobile := ``

	for _, v := range userList {
		mobile += v.Mobile + ","
	}

	mobile = strings.TrimRight(mobile, ",")

	openIdList, e := models.GetWxOpenIdByMobileList(mobile)
	if e != nil {
		err = errors.New("GetSellerByAdminId, Err: " + e.Error())
		return
	}

	//first =
	keyword1 = "研选专栏：" + specialItem.SpecialName
	keyword2 = "发布了新内容，点击查看详情"
	keyword3 = "-"
	//keyword4 = "【" + activityInfo.ResearchTheme + "】已有10人预报名"
	openIdArr := make([]string, 0)
	for _, v := range openIdList {
		openIdArr = append(openIdArr, v.OpenId)
	}
	redirectUrl := ""
	if utils.RunMode == "release" {
		redirectUrl = utils.WX_MSG_PATH_YX_SPECIAL_DETAIL + strconv.Itoa(specialId)
	}
	sendInfo := new(SendWxTemplate)
	sendInfo.First = first
	sendInfo.Keyword1 = keyword1
	sendInfo.Keyword2 = keyword2
	sendInfo.Keyword3 = keyword3
	sendInfo.Keyword4 = keyword4
	sendInfo.Remark = remark
	sendInfo.TemplateId = utils.WxMsgTemplateIdAskMsgXzs
	sendInfo.RedirectUrl = redirectUrl
	sendInfo.RedirectTarget = 3
	sendInfo.Resource = strconv.Itoa(specialId)
	sendInfo.SendType = utils.TEMPLATE_MSG_CYGX_ARTICLE_ADD
	sendInfo.OpenIdArr = openIdArr
	err = PublicSendTemplateMsg(sendInfo)
	if err != nil {
		return
	}
	return
}

// SendReviewTemplateMsgAdmin 提交审核时给王芳，汪洋发消息
func SendReviewTemplateMsgAdmin(specialId int) (err error) {
	defer func() {
		if err != nil {
			go utils.SendAlarmMsg("处理试用申请给王芳，汪洋发消息失败, ErrMsg: "+err.Error(), 3)
		}
	}()
	var configCode string
	//如果是研选的就推送给汪洋跟王芳，否则就推送给王芳
	configCode = utils.TPL_MSG_WANG_FANG_WANG_YANG
	cnf, e := models.GetConfigByCode(configCode)
	if e != nil {
		err = errors.New("GetConfigByCode, Err: " + e.Error() + configCode)
		return
	}
	openIdList, e := models.GetUserRecordListByMobile(4, cnf.ConfigValue)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetUserRecordListByMobile, Err: " + e.Error() + cnf.ConfigValue)
		return err
	}
	specialItem, e := models.GetYanxuanSpecialItemById(specialId)
	if e != nil {
		err = errors.New("GetYanxuanSpecialFollowUserById, Err: " + e.Error())
		return
	}
	user, e := models.GetWxUserItemByUserId(specialItem.UserId)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetWxUserItemByUserId, Err: " + e.Error())
		return err
	}
	var keyword1 string
	var keyword2 string
	var keyword3 string
	var keyword4 string
	var remark string
	keyword1 = specialItem.RealName + "【" + user.CompanyName + "】"
	keyword2 = user.Mobile
	keyword3 = time.Now().Format(utils.FormatDateTime)
	keyword4 = "研选专栏提交了内容待审核"
	openIdArr := make([]string, 0)
	for _, v := range openIdList {
		openIdArr = append(openIdArr, v.OpenId)
	}
	redirectUrl := ""
	if utils.RunMode == "release" {
		redirectUrl = utils.WX_MSG_PATH_YX_SPECIAL_ENABLE_DETAIL + strconv.Itoa(specialId)
	}
	sendInfo := new(SendWxTemplate)
	sendInfo.Keyword1 = keyword1
	sendInfo.Keyword2 = keyword2
	sendInfo.Keyword3 = keyword3
	sendInfo.Keyword4 = keyword4
	sendInfo.Remark = remark
	sendInfo.TemplateId = utils.WxMsgTemplateIdAskMsgXzs
	sendInfo.RedirectUrl = redirectUrl
	sendInfo.RedirectTarget = 3
	sendInfo.Resource = strconv.Itoa(specialId)
	sendInfo.SendType = utils.TEMPLATE_MSG_CYGX_ARTICLE_ADD
	sendInfo.OpenIdArr = openIdArr
	err = PublicSendTemplateMsg(sendInfo)
	if err != nil {
		return
	}
	return
}

// 研选专栏审核完成时，给提交人发送模板消息
func SendWxMsgSpecialAuthor(specialId, status int) (err error) {
	var msg string
	defer func() {
		if err != nil {
			go utils.SendEmail("发送模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format("2006-01-02 15:04:05"), msg+";Err:"+err.Error(), utils.EmailSendToUsers)
			go utils.SendAlarmMsg(fmt.Sprint("研选专栏审核完成时，给提交人发送模板消息", specialId, ", specialId"), 2)
			utils.FileLog.Info("发送模版消息失败,Err:%s", err.Error())
		}
	}()
	var first string
	var keyword1 string
	var keyword2 string
	var keyword3 string
	var keyword4 string
	var remark string
	var redirectUrl string

	specialItem, e := models.GetYanxuanSpecialItemById(specialId)
	if e != nil {
		err = errors.New("GetYanxuanSpecialFollowUserById, Err: " + e.Error())
		return
	}
	user, e := models.GetWxUserItemByUserId(specialItem.UserId)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetWxUserItemByUserId, Err: " + e.Error())
		return err
	}

	openIdList, err := models.GetUserRecordListByMobile(4, user.Mobile)
	if err != nil && err.Error() != utils.ErrNoRow() {
		return err
	}

	//first =
	keyword1 = "研选专栏内容审核"
	if status == 1 {
		keyword2 = "已通过审核，点击查看详情"
		if utils.RunMode == "release" {
			redirectUrl = utils.WX_MSG_PATH_YX_SPECIAL_DETAIL + strconv.Itoa(specialId)
		}
	} else {
		keyword2 = "未通过审核，点击查看驳回原因"
		if utils.RunMode == "release" {
			redirectUrl = utils.WX_MSG_PATH_YX_SPECIAL_CENTER
		}
	}

	keyword3 = "-"
	//keyword4 = "【" + activityInfo.ResearchTheme + "】已有10人预报名"
	openIdArr := make([]string, 0)
	for _, v := range openIdList {
		openIdArr = append(openIdArr, v.OpenId)
	}
	sendInfo := new(SendWxTemplate)
	sendInfo.First = first
	sendInfo.Keyword1 = keyword1
	sendInfo.Keyword2 = keyword2
	sendInfo.Keyword3 = keyword3
	sendInfo.Keyword4 = keyword4
	sendInfo.Remark = remark
	sendInfo.TemplateId = utils.WxMsgTemplateIdAskMsgXzs
	sendInfo.RedirectUrl = redirectUrl
	sendInfo.RedirectTarget = 3
	sendInfo.Resource = strconv.Itoa(specialId)
	sendInfo.SendType = utils.TEMPLATE_MSG_CYGX_ARTICLE_ADD
	sendInfo.OpenIdArr = openIdArr
	err = PublicSendTemplateMsg(sendInfo)
	if err != nil {
		return
	}
	return
}

//func init() {
//	UpdateYanxuanSpecialResourceData(185)
//}

// 更新研选专栏  写入首页最新  cygx_resource_data 表
func UpdateYanxuanSpecialResourceData(sourceId int) {
	var err error
	defer func() {
		if err != nil {
			go utils.SendAlarmMsg(fmt.Sprint("更新研选专栏失败ourceId: ", sourceId), 2)
		}
	}()
	var source = utils.CYGX_OBJ_YANXUANSPECIAL
	var condition string
	var pars []interface{}
	condition = ` AND status = 3  AND  id = ?  `
	pars = append(pars, sourceId)
	total, e := models.GetCygxYanxuanSpecialCount(condition, pars)
	if e != nil {
		err = errors.New("GetCygxYanxuanSpecialCount, Err: " + e.Error())
		return
	}
	//如果取消发布了就做删除处理
	if total == 0 {
		e = models.DeleteResourceData(sourceId, source)
		if e != nil {
			err = errors.New("DeleteResourceData, Err: " + e.Error())
			return
		}
	} else {
		//判断是否存在，如果不存在就新增，存在就更新
		totalData, e := models.GetCygxResourceDataBySourceAndIdCount(sourceId, source)
		if e != nil {
			err = errors.New("GetCygxReportSelectionBySourceAndId, Err: " + e.Error())
			return
		}
		publishDate := time.Now().Format(utils.FormatDateTime)
		item := new(models.CygxResourceData)
		item.SourceId = sourceId
		item.Source = source
		item.PublishDate = publishDate
		item.CreateTime = time.Now()
		if totalData == 0 {
			_, e := models.AddCygxResourceData(item)
			if e != nil {
				err = errors.New("AddCygxResourceData, Err: " + e.Error())
				return
			}
		} else {
			e = models.UpdateResourceDataByItem(item)
			if e != nil {
				err = errors.New("UpdateResourceDataByItem, Err: " + e.Error())
				return
			}
		}
	}
	return
}
